%% Holy grail test script:
% defines, inits and sets up cfs1 and cfs2 algo obj
% actulizes them on -1
% configures an interlaced cfs1 / cfs2 simulation model
% simulates it, storing outputs in th ebase workspace
% builds cfs1 and cfs2 .so libs
% builds MARTe2 dual thread cfs1 and cfs2 cfg file
% transfers these to realtime machine
% runs 1 MARTe2 run of cfs1 and cfs2
% retrieves the outputs from MDSplus
% plots the sim vs realtime signals (some of them)

%% cfs1 and cfs2 algo objects configuration
obj1=algoobj_cfs1; obj1.init; obj1.setup;
obj2=algoobj_cfs2; obj2.init; obj2.setup;

%% test shot actualization (model, to cope with MARTe2 settings)
shot=-1;
obj1.actualize(shot);
obj2.actualize(shot);

%% Workaround to define proc buses in one place only
% NOTE: this is not to be replicated,
% an higher hyerarchical SCDDS level must be put in place
% to do it properly
dd1=Simulink.data.dictionary.open('algo_cfs1.sldd');
ddd1=dd1.getSection('Design Data');
ddd1.deleteEntry('algo_cfs2_procout');
% 
dd2=Simulink.data.dictionary.open('algo_cfs2.sldd');
ddd2=dd2.getSection('Design Data');
ddd2.deleteEntry('algo_cfs1_procout');
% 
dd1.addDataSource('algo_cfs2.sldd');
dd2.addDataSource('algo_cfs1.sldd');

%% Simulink simulation
sim('cfs12combined_test');

%% cfs1 and cfs2 build
SCDconf_setConf('configurationSettingsCODEgcc');
load_system('algo_cfs1');
rtwbuild('algo_cfs1');

load_system('algo_cfs2');
rtwbuild('algo_cfs2');

%% MARTe2 cfg file autogeneration
cd marte2cfg/2threads/
algo_cfs1and2_create_marte2_cfg;
cd ../..

%% Transfer gencode and cfg to the realtime machine
system('scp marte2cfg/2threads/algo_cfs1and2_2threads.cfg root@node06:/root/MARTe2-examples/Configurations');
system('scp ../../../gencodes/CodeGenFolder/algo_cfs1.so  root@node06:/root/MARTe2-examples/Simulinkso');
system('scp ../../../gencodes/CodeGenFolder/algo_cfs2.so  root@node06:/root/MARTe2-examples/Simulinkso');

%% MARTe2 run of the same thing, on the realtime machine
system('ssh root@node06 ''source /etc/profile; cd MARTe2-examples; ./runcfs.sh''');

%% Gets MARTe2 outputs 
mdsconnect('scd');
marteshot=mdsopen('scdds',0)

cfs1signal1marte2=tdi('cfs1.outputs.signal1');
cfs1signal2marte2=tdi('cfs1.outputs.signal2');
cfs1signal3marte2=tdi('cfs1.outputs.signal3');
cfs2signal1marte2=tdi('cfs2.outputs.signal1');
cfs2signal2marte2=tdi('cfs2.outputs.signal2');
cfs2signal3marte2=tdi('cfs2.outputs.signal3');

%% Plot combined simulation / realtime ouput signals
figure(1);
clf
hold on

plot(cfs1simout.signal1,'k--');%'LineWidth',4);
plot(cfs1simout.signal2,'k--');%'LineWidth',4);
plot(cfs1simout.signal3,'k--');%'LineWidth',4);
plot(cfs2simout.signal1,'k--');%'LineWidth',4);
plot(cfs2simout.signal2,'k--');%'LineWidth',4);
plot(cfs2simout.signal3,'k--');%'LineWidth',4);

plot(cfs1signal1marte2,'r');
plot(cfs1signal2marte2,'r');
plot(cfs1signal3marte2,'r');
plot(cfs2signal1marte2,'r');
plot(cfs2signal2marte2,'r');
plot(cfs2signal3marte2,'r');

xlim([0 3]);
grid on




